/*-
 * ============LICENSE_START=======================================================
 * ONAP - SO
 * ================================================================================
 * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.onap.so.adapters.requestsdb.application;

import javax.xml.ws.Endpoint;

import org.apache.cxf.Bus;
import org.apache.cxf.feature.LoggingFeature;
import org.apache.cxf.jaxrs.swagger.Swagger2Feature;
import org.apache.cxf.jaxws.EndpointImpl;
import org.apache.cxf.transport.servlet.CXFServlet;
import org.onap.so.adapters.requestsdb.MsoRequestsDbAdapter;
import org.onap.so.logging.cxf.interceptor.SOAPLoggingInInterceptor;
import org.onap.so.logging.cxf.interceptor.SOAPLoggingOutInterceptor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.web.servlet.ServletRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;


@Configuration
public class CXFConfiguration {

	@Autowired
	private Bus bus;

	@Autowired
	private MsoRequestsDbAdapter requestDbAdapterImpl;
	
	@Autowired
	private SOAPLoggingInInterceptor soapInInterceptor;
	
	@Autowired
	private SOAPLoggingOutInterceptor soapOutInterceptor;
	
	@Bean
	public ServletRegistrationBean cxfServlet() {
	
		return new ServletRegistrationBean(new CXFServlet(), "/services/*");
	}

	@Bean
	public Endpoint requestEndpointk() {
		EndpointImpl endpoint = new EndpointImpl(bus, requestDbAdapterImpl);
		endpoint.publish("/RequestsDbAdapter");
		LoggingFeature logFeature = new LoggingFeature();
		logFeature.setPrettyLogging(true);
		logFeature.initialize(bus);
		endpoint.getFeatures().add(logFeature);
		endpoint.getInInterceptors().add(soapInInterceptor);
		endpoint.getOutInterceptors().add(soapOutInterceptor);
		endpoint.getOutFaultInterceptors().add(soapOutInterceptor);
		return endpoint;
	}

	@Bean
	public Swagger2Feature createSwaggerFeature() {
		Swagger2Feature swagger2Feature = new Swagger2Feature();
		swagger2Feature.setPrettyPrint(true);
		swagger2Feature.setTitle("SO Request Adapter");
		swagger2Feature.setContact("The ONAP SO team");
		swagger2Feature.setDescription("This project is the SO Orchestration Engine");
		swagger2Feature.setVersion("1.0.0");
		swagger2Feature.setResourcePackage("org.onap.so.adapters.requestdb");
		swagger2Feature.setScan(true);
		return swagger2Feature;
	}

}
